ChiantiPy\.tests package
========================

Submodules
----------

ChiantiPy\.tests\.setup\_package module
---------------------------------------

.. automodule:: ChiantiPy.tests.setup_package
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ChiantiPy.tests
    :members:
    :undoc-members:
    :show-inheritance:
